# mypy-boto3-mediaconvert

[![PyPI - mypy-boto3-mediaconvert](https://img.shields.io/pypi/v/mypy-boto3-mediaconvert.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediaconvert)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-mediaconvert.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediaconvert)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-mediaconvert?color=blue)](https://pypistats.org/packages/mypy-boto3-mediaconvert)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.MediaConvert 1.17.65](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/mediaconvert.html#MediaConvert)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-mediaconvert docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_mediaconvert/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-mediaconvert](#mypy-boto3-mediaconvert)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `MediaConvert` service.

```bash
python -m pip install boto3-stubs[mediaconvert]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[mediaconvert]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconvert]'`

Both type checking and auto-complete should work for `MediaConvert` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[mediaconvert]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconvert]'`

Both type checking and auto-complete should work for `MediaConvert` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[mediaconvert]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconvert]'`
- Run `mypy` as usual

Type checking should work for `MediaConvert` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[mediaconvert]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconvert]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MediaConvert` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`MediaConvertClient` provides annotations for `boto3.client("mediaconvert")`.

```python
import boto3

from mypy_boto3_mediaconvert import MediaConvertClient

client: MediaConvertClient = boto3.client("mediaconvert")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MediaConvertClient = session.client("mediaconvert")
```

### Paginators annotations

`mypy_boto3_mediaconvert.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_mediaconvert import MediaConvertClient
from mypy_boto3_mediaconvert.paginator import (
    DescribeEndpointsPaginator,
    ListJobTemplatesPaginator,
    ListJobsPaginator,
    ListPresetsPaginator,
    ListQueuesPaginator,
)

client: MediaConvertClient = boto3.client("mediaconvert")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_endpoints_paginator: DescribeEndpointsPaginator = client.get_paginator("describe_endpoints")
list_job_templates_paginator: ListJobTemplatesPaginator = client.get_paginator("list_job_templates")
list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
list_presets_paginator: ListPresetsPaginator = client.get_paginator("list_presets")
list_queues_paginator: ListQueuesPaginator = client.get_paginator("list_queues")
```

### Literals

`mypy_boto3_mediaconvert.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_mediaconvert.literals import (
    AacAudioDescriptionBroadcasterMix,
    AacCodecProfile,
    AacCodingMode,
    AacRateControlMode,
    AacRawFormat,
    AacSpecification,
    AacVbrQuality,
    Ac3BitstreamMode,
    Ac3CodingMode,
    Ac3DynamicRangeCompressionLine,
    Ac3DynamicRangeCompressionProfile,
    Ac3DynamicRangeCompressionRf,
    Ac3LfeFilter,
    Ac3MetadataControl,
    AccelerationMode,
    AccelerationStatus,
    AfdSignaling,
    AlphaBehavior,
    AncillaryConvert608To708,
    AncillaryTerminateCaptions,
    AntiAlias,
    AudioChannelTag,
    AudioCodec,
    AudioDefaultSelection,
    AudioLanguageCodeControl,
    AudioNormalizationAlgorithm,
    AudioNormalizationAlgorithmControl,
    AudioNormalizationLoudnessLogging,
    AudioNormalizationPeakCalculation,
    AudioSelectorType,
    AudioTypeControl,
    Av1AdaptiveQuantization,
    Av1FramerateControl,
    Av1FramerateConversionAlgorithm,
    Av1RateControlMode,
    Av1SpatialAdaptiveQuantization,
    AvcIntraClass,
    AvcIntraFramerateControl,
    AvcIntraFramerateConversionAlgorithm,
    AvcIntraInterlaceMode,
    AvcIntraScanTypeConversionMode,
    AvcIntraSlowPal,
    AvcIntraTelecine,
    AvcIntraUhdQualityTuningLevel,
    BillingTagsSource,
    BurninSubtitleAlignment,
    BurninSubtitleBackgroundColor,
    BurninSubtitleFontColor,
    BurninSubtitleOutlineColor,
    BurninSubtitleShadowColor,
    BurninSubtitleTeletextSpacing,
    CaptionDestinationType,
    CaptionSourceType,
    CmafClientCache,
    CmafCodecSpecification,
    CmafEncryptionType,
    CmafInitializationVectorInManifest,
    CmafKeyProviderType,
    CmafManifestCompression,
    CmafManifestDurationFormat,
    CmafMpdProfile,
    CmafPtsOffsetHandlingForBFrames,
    CmafSegmentControl,
    CmafStreamInfResolution,
    CmafWriteDASHManifest,
    CmafWriteHLSManifest,
    CmafWriteSegmentTimelineInRepresentation,
    CmfcAudioDuration,
    CmfcAudioTrackType,
    CmfcDescriptiveVideoServiceFlag,
    CmfcIFrameOnlyManifest,
    CmfcScte35Esam,
    CmfcScte35Source,
    ColorMetadata,
    ColorSpace,
    ColorSpaceConversion,
    ColorSpaceUsage,
    Commitment,
    ContainerType,
    DashIsoGroupAudioChannelConfigSchemeIdUri,
    DashIsoHbbtvCompliance,
    DashIsoMpdProfile,
    DashIsoPlaybackDeviceCompatibility,
    DashIsoPtsOffsetHandlingForBFrames,
    DashIsoSegmentControl,
    DashIsoWriteSegmentTimelineInRepresentation,
    DecryptionMode,
    DeinterlaceAlgorithm,
    DeinterlacerControl,
    DeinterlacerMode,
    DescribeEndpointsMode,
    DescribeEndpointsPaginatorName,
    DolbyVisionLevel6Mode,
    DolbyVisionProfile,
    DropFrameTimecode,
    DvbSubtitleAlignment,
    DvbSubtitleBackgroundColor,
    DvbSubtitleFontColor,
    DvbSubtitleOutlineColor,
    DvbSubtitleShadowColor,
    DvbSubtitleTeletextSpacing,
    DvbSubtitlingType,
    Eac3AtmosBitstreamMode,
    Eac3AtmosCodingMode,
    Eac3AtmosDialogueIntelligence,
    Eac3AtmosDynamicRangeCompressionLine,
    Eac3AtmosDynamicRangeCompressionRf,
    Eac3AtmosMeteringMode,
    Eac3AtmosStereoDownmix,
    Eac3AtmosSurroundExMode,
    Eac3AttenuationControl,
    Eac3BitstreamMode,
    Eac3CodingMode,
    Eac3DcFilter,
    Eac3DynamicRangeCompressionLine,
    Eac3DynamicRangeCompressionRf,
    Eac3LfeControl,
    Eac3LfeFilter,
    Eac3MetadataControl,
    Eac3PassthroughControl,
    Eac3PhaseControl,
    Eac3StereoDownmix,
    Eac3SurroundExMode,
    Eac3SurroundMode,
    EmbeddedConvert608To708,
    EmbeddedTerminateCaptions,
    F4vMoovPlacement,
    FileSourceConvert608To708,
    FontScript,
    H264AdaptiveQuantization,
    H264CodecLevel,
    H264CodecProfile,
    H264DynamicSubGop,
    H264EntropyEncoding,
    H264FieldEncoding,
    H264FlickerAdaptiveQuantization,
    H264FramerateControl,
    H264FramerateConversionAlgorithm,
    H264GopBReference,
    H264GopSizeUnits,
    H264InterlaceMode,
    H264ParControl,
    H264QualityTuningLevel,
    H264RateControlMode,
    H264RepeatPps,
    H264ScanTypeConversionMode,
    H264SceneChangeDetect,
    H264SlowPal,
    H264SpatialAdaptiveQuantization,
    H264Syntax,
    H264Telecine,
    H264TemporalAdaptiveQuantization,
    H264UnregisteredSeiTimecode,
    H265AdaptiveQuantization,
    H265AlternateTransferFunctionSei,
    H265CodecLevel,
    H265CodecProfile,
    H265DynamicSubGop,
    H265FlickerAdaptiveQuantization,
    H265FramerateControl,
    H265FramerateConversionAlgorithm,
    H265GopBReference,
    H265GopSizeUnits,
    H265InterlaceMode,
    H265ParControl,
    H265QualityTuningLevel,
    H265RateControlMode,
    H265SampleAdaptiveOffsetFilterMode,
    H265ScanTypeConversionMode,
    H265SceneChangeDetect,
    H265SlowPal,
    H265SpatialAdaptiveQuantization,
    H265Telecine,
    H265TemporalAdaptiveQuantization,
    H265TemporalIds,
    H265Tiles,
    H265UnregisteredSeiTimecode,
    H265WriteMp4PackagingType,
    HlsAdMarkers,
    HlsAudioOnlyContainer,
    HlsAudioOnlyHeader,
    HlsAudioTrackType,
    HlsCaptionLanguageSetting,
    HlsClientCache,
    HlsCodecSpecification,
    HlsDescriptiveVideoServiceFlag,
    HlsDirectoryStructure,
    HlsEncryptionType,
    HlsIFrameOnlyManifest,
    HlsInitializationVectorInManifest,
    HlsKeyProviderType,
    HlsManifestCompression,
    HlsManifestDurationFormat,
    HlsOfflineEncrypted,
    HlsOutputSelection,
    HlsProgramDateTime,
    HlsSegmentControl,
    HlsStreamInfResolution,
    HlsTimedMetadataId3Frame,
    ImscStylePassthrough,
    InputDeblockFilter,
    InputDenoiseFilter,
    InputFilterEnable,
    InputPsiControl,
    InputRotate,
    InputScanType,
    InputTimecodeSource,
    JobPhase,
    JobStatus,
    JobTemplateListBy,
    LanguageCode,
    ListJobTemplatesPaginatorName,
    ListJobsPaginatorName,
    ListPresetsPaginatorName,
    ListQueuesPaginatorName,
    M2tsAudioBufferModel,
    M2tsAudioDuration,
    M2tsBufferModel,
    M2tsEbpAudioInterval,
    M2tsEbpPlacement,
    M2tsEsRateInPes,
    M2tsForceTsVideoEbpOrder,
    M2tsNielsenId3,
    M2tsPcrControl,
    M2tsRateMode,
    M2tsScte35Source,
    M2tsSegmentationMarkers,
    M2tsSegmentationStyle,
    M3u8AudioDuration,
    M3u8NielsenId3,
    M3u8PcrControl,
    M3u8Scte35Source,
    MotionImageInsertionMode,
    MotionImagePlayback,
    MovClapAtom,
    MovCslgAtom,
    MovMpeg2FourCCControl,
    MovPaddingControl,
    MovReference,
    Mp3RateControlMode,
    Mp4CslgAtom,
    Mp4FreeSpaceBox,
    Mp4MoovPlacement,
    MpdAccessibilityCaptionHints,
    MpdAudioDuration,
    MpdCaptionContainerType,
    MpdScte35Esam,
    MpdScte35Source,
    Mpeg2AdaptiveQuantization,
    Mpeg2CodecLevel,
    Mpeg2CodecProfile,
    Mpeg2DynamicSubGop,
    Mpeg2FramerateControl,
    Mpeg2FramerateConversionAlgorithm,
    Mpeg2GopSizeUnits,
    Mpeg2InterlaceMode,
    Mpeg2IntraDcPrecision,
    Mpeg2ParControl,
    Mpeg2QualityTuningLevel,
    Mpeg2RateControlMode,
    Mpeg2ScanTypeConversionMode,
    Mpeg2SceneChangeDetect,
    Mpeg2SlowPal,
    Mpeg2SpatialAdaptiveQuantization,
    Mpeg2Syntax,
    Mpeg2Telecine,
    Mpeg2TemporalAdaptiveQuantization,
    MsSmoothAudioDeduplication,
    MsSmoothManifestEncoding,
    MxfAfdSignaling,
    MxfProfile,
    NielsenActiveWatermarkProcessType,
    NielsenSourceWatermarkStatusType,
    NielsenUniqueTicPerAudioTrackType,
    NoiseFilterPostTemporalSharpening,
    NoiseReducerFilter,
    Order,
    OutputGroupType,
    OutputSdt,
    PresetListBy,
    PricingPlan,
    ProresCodecProfile,
    ProresFramerateControl,
    ProresFramerateConversionAlgorithm,
    ProresInterlaceMode,
    ProresParControl,
    ProresScanTypeConversionMode,
    ProresSlowPal,
    ProresTelecine,
    QueueListBy,
    QueueStatus,
    RenewalType,
    ReservationPlanStatus,
    RespondToAfd,
    S3ObjectCannedAcl,
    S3ServerSideEncryptionType,
    ScalingBehavior,
    SccDestinationFramerate,
    SimulateReservedQueue,
    StatusUpdateInterval,
    TeletextPageType,
    TimecodeBurninPosition,
    TimecodeSource,
    TimedMetadata,
    TtmlStylePassthrough,
    TypeType,
    Vc3Class,
    Vc3FramerateControl,
    Vc3FramerateConversionAlgorithm,
    Vc3InterlaceMode,
    Vc3ScanTypeConversionMode,
    Vc3SlowPal,
    Vc3Telecine,
    VideoCodec,
    VideoTimecodeInsertion,
    Vp8FramerateControl,
    Vp8FramerateConversionAlgorithm,
    Vp8ParControl,
    Vp8QualityTuningLevel,
    Vp8RateControlMode,
    Vp9FramerateControl,
    Vp9FramerateConversionAlgorithm,
    Vp9ParControl,
    Vp9QualityTuningLevel,
    Vp9RateControlMode,
    WatermarkingStrength,
    WavFormat,
    WebvttStylePassthrough,
)

def check_value(value: AacAudioDescriptionBroadcasterMix) -> bool:
    ...
```

### Typed dictionaries

`mypy_boto3_mediaconvert.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_mediaconvert.type_defs import (
    AacSettingsTypeDef,
    Ac3SettingsTypeDef,
    AccelerationSettingsTypeDef,
    AiffSettingsTypeDef,
    AncillarySourceSettingsTypeDef,
    AudioChannelTaggingSettingsTypeDef,
    AudioCodecSettingsTypeDef,
    AudioDescriptionTypeDef,
    AudioNormalizationSettingsTypeDef,
    AudioSelectorGroupTypeDef,
    AudioSelectorTypeDef,
    AutomatedAbrSettingsTypeDef,
    AutomatedEncodingSettingsTypeDef,
    Av1QvbrSettingsTypeDef,
    Av1SettingsTypeDef,
    AvailBlankingTypeDef,
    AvcIntraSettingsTypeDef,
    AvcIntraUhdSettingsTypeDef,
    BurninDestinationSettingsTypeDef,
    CaptionDescriptionPresetTypeDef,
    CaptionDescriptionTypeDef,
    CaptionDestinationSettingsTypeDef,
    CaptionSelectorTypeDef,
    CaptionSourceFramerateTypeDef,
    CaptionSourceSettingsTypeDef,
    ChannelMappingTypeDef,
    CmafAdditionalManifestTypeDef,
    CmafEncryptionSettingsTypeDef,
    CmafGroupSettingsTypeDef,
    CmfcSettingsTypeDef,
    ColorCorrectorTypeDef,
    ContainerSettingsTypeDef,
    CreateJobResponseTypeDef,
    CreateJobTemplateResponseTypeDef,
    CreatePresetResponseTypeDef,
    CreateQueueResponseTypeDef,
    DashAdditionalManifestTypeDef,
    DashIsoEncryptionSettingsTypeDef,
    DashIsoGroupSettingsTypeDef,
    DeinterlacerTypeDef,
    DescribeEndpointsResponseTypeDef,
    DestinationSettingsTypeDef,
    DolbyVisionLevel6MetadataTypeDef,
    DolbyVisionTypeDef,
    DvbNitSettingsTypeDef,
    DvbSdtSettingsTypeDef,
    DvbSubDestinationSettingsTypeDef,
    DvbSubSourceSettingsTypeDef,
    DvbTdtSettingsTypeDef,
    Eac3AtmosSettingsTypeDef,
    Eac3SettingsTypeDef,
    EmbeddedDestinationSettingsTypeDef,
    EmbeddedSourceSettingsTypeDef,
    EndpointTypeDef,
    EsamManifestConfirmConditionNotificationTypeDef,
    EsamSettingsTypeDef,
    EsamSignalProcessingNotificationTypeDef,
    F4vSettingsTypeDef,
    FileGroupSettingsTypeDef,
    FileSourceSettingsTypeDef,
    FrameCaptureSettingsTypeDef,
    GetJobResponseTypeDef,
    GetJobTemplateResponseTypeDef,
    GetPresetResponseTypeDef,
    GetQueueResponseTypeDef,
    H264QvbrSettingsTypeDef,
    H264SettingsTypeDef,
    H265QvbrSettingsTypeDef,
    H265SettingsTypeDef,
    Hdr10MetadataTypeDef,
    HlsAdditionalManifestTypeDef,
    HlsCaptionLanguageMappingTypeDef,
    HlsEncryptionSettingsTypeDef,
    HlsGroupSettingsTypeDef,
    HlsSettingsTypeDef,
    HopDestinationTypeDef,
    Id3InsertionTypeDef,
    ImageInserterTypeDef,
    ImscDestinationSettingsTypeDef,
    InputClippingTypeDef,
    InputDecryptionSettingsTypeDef,
    InputTemplateTypeDef,
    InputTypeDef,
    InsertableImageTypeDef,
    JobMessagesTypeDef,
    JobSettingsTypeDef,
    JobTemplateSettingsTypeDef,
    JobTemplateTypeDef,
    JobTypeDef,
    ListJobTemplatesResponseTypeDef,
    ListJobsResponseTypeDef,
    ListPresetsResponseTypeDef,
    ListQueuesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    M2tsScte35EsamTypeDef,
    M2tsSettingsTypeDef,
    M3u8SettingsTypeDef,
    MotionImageInserterTypeDef,
    MotionImageInsertionFramerateTypeDef,
    MotionImageInsertionOffsetTypeDef,
    MovSettingsTypeDef,
    Mp2SettingsTypeDef,
    Mp3SettingsTypeDef,
    Mp4SettingsTypeDef,
    MpdSettingsTypeDef,
    Mpeg2SettingsTypeDef,
    MsSmoothAdditionalManifestTypeDef,
    MsSmoothEncryptionSettingsTypeDef,
    MsSmoothGroupSettingsTypeDef,
    MxfSettingsTypeDef,
    NexGuardFileMarkerSettingsTypeDef,
    NielsenConfigurationTypeDef,
    NielsenNonLinearWatermarkSettingsTypeDef,
    NoiseReducerFilterSettingsTypeDef,
    NoiseReducerSpatialFilterSettingsTypeDef,
    NoiseReducerTemporalFilterSettingsTypeDef,
    NoiseReducerTypeDef,
    OpusSettingsTypeDef,
    OutputChannelMappingTypeDef,
    OutputDetailTypeDef,
    OutputGroupDetailTypeDef,
    OutputGroupSettingsTypeDef,
    OutputGroupTypeDef,
    OutputSettingsTypeDef,
    OutputTypeDef,
    PaginatorConfigTypeDef,
    PartnerWatermarkingTypeDef,
    PresetSettingsTypeDef,
    PresetTypeDef,
    ProresSettingsTypeDef,
    QueueTransitionTypeDef,
    QueueTypeDef,
    RectangleTypeDef,
    RemixSettingsTypeDef,
    ReservationPlanSettingsTypeDef,
    ReservationPlanTypeDef,
    ResourceTagsTypeDef,
    ResponseMetadata,
    S3DestinationAccessControlTypeDef,
    S3DestinationSettingsTypeDef,
    S3EncryptionSettingsTypeDef,
    SccDestinationSettingsTypeDef,
    SpekeKeyProviderCmafTypeDef,
    SpekeKeyProviderTypeDef,
    StaticKeyProviderTypeDef,
    TeletextDestinationSettingsTypeDef,
    TeletextSourceSettingsTypeDef,
    TimecodeBurninTypeDef,
    TimecodeConfigTypeDef,
    TimedMetadataInsertionTypeDef,
    TimingTypeDef,
    TrackSourceSettingsTypeDef,
    TtmlDestinationSettingsTypeDef,
    UpdateJobTemplateResponseTypeDef,
    UpdatePresetResponseTypeDef,
    UpdateQueueResponseTypeDef,
    Vc3SettingsTypeDef,
    VideoCodecSettingsTypeDef,
    VideoDescriptionTypeDef,
    VideoDetailTypeDef,
    VideoPreprocessorTypeDef,
    VideoSelectorTypeDef,
    VorbisSettingsTypeDef,
    Vp8SettingsTypeDef,
    Vp9SettingsTypeDef,
    WavSettingsTypeDef,
    WebvttDestinationSettingsTypeDef,
)

def get_structure() -> AacSettingsTypeDef:
    return {
      ...
    }
```
